@@ -23,14 +23,17 @@ namespace eckit {
 
 class CmdApplication : public Prompter {
 public:
+
     CmdApplication();
     virtual ~CmdApplication();
 
 protected:
+
     void execute();
 
 private:
-    virtual std::string prompt() const override;
+
+    std::string prompt() const override;
     virtual std::string name() const;
 
     void startup(std::ostream&);
