@@ -32,8 +32,7 @@ namespace eckit {
 //----------------------------------------------------------------------------------------------------------------------
 
 struct EventNotFound : public Exception {
-    EventNotFound(const std::string& s) :
-        Exception(s + ": Event not found") {}
+    EventNotFound(const std::string& s) : Exception(s + ": Event not found") {}
 };
 
 typedef std::stack<CmdParser*, std::vector<CmdParser*> > ParserStack;
@@ -64,8 +63,6 @@ static History history_;
 // For Lex
 static bool eckit_cmd_debug_;
 
-static long pos_ = 0;
-
 //----------------------------------------------------------------------------------------------------------------------
 
 namespace CmdYacc {
@@ -94,7 +91,6 @@ void eckit_cmd_error(const char* msg) {
 
 void CmdParser::parse(const std::string& line, std::ostream& out) {
     command_ = line;
-    pos_     = 0;
     out_     = &out;
 
     if (command_.size() > 0) {
@@ -153,7 +149,6 @@ void CmdParser::parse(std::istream& in, std::ostream& out, const Prompter& promp
         }
 
         command_ = p;
-        pos_     = 0;
 
         if (command_.size() > 0) {
             // Prepare for parse
@@ -383,8 +378,7 @@ void CmdParser::substitute() {
 //----------------------------------------------------------------------------------------------------------------------
 
 void CmdParser::run(void (*proc)(CmdResource*, CmdArg&, std::istream&, std::ostream&)) {
-    Log::debug() << "Executing " << std::endl
-                 << arg_ << std::endl;
+    Log::debug() << "Executing " << std::endl << arg_ << std::endl;
 
     if (flags_['x']) {
         Log::info() << command_ << std::flush;
