@@ -25,6 +25,7 @@ namespace eckit {
 
 class EchoCmd : public CmdResource {
 public:
+
     // -- Contructors
 
     EchoCmd();
@@ -34,6 +35,7 @@ public:
     ~EchoCmd();
 
 private:
+
     // No copy allowed
 
     EchoCmd(const EchoCmd&);
@@ -43,10 +45,10 @@ private:
 
     // From CmdResource
 
-    virtual void execute(std::istream&, std::ostream&, CmdArg&) override;
+    void execute(std::istream&, std::ostream&, CmdArg&) override;
 
-    virtual void help(std::ostream&) const override;
-    virtual Arg usage(const std::string& cmd) const override;
+    void help(std::ostream&) const override;
+    Arg usage(const std::string& cmd) const override;
 };
 
 //-----------------------------------------------------------------------------
