@@ -25,6 +25,7 @@ namespace eckit {
 
 class QuitCmd : public CmdResource {
 public:
+
     // -- Contructors
 
     QuitCmd();
@@ -34,6 +35,7 @@ public:
     ~QuitCmd();
 
 private:
+
     // No copy allowed
 
     QuitCmd(const QuitCmd&);
@@ -43,13 +45,13 @@ private:
 
     // From CmdResource
 
-    virtual void execute(std::istream&, std::ostream& out, CmdArg&);
-    virtual void help(std::ostream&) const;
-    virtual Arg usage(const std::string& cmd) const;
+    void execute(std::istream&, std::ostream& out, CmdArg&) override;
+    void help(std::ostream&) const override;
+    Arg usage(const std::string& cmd) const override;
 };
 
 //-----------------------------------------------------------------------------
 
-} // namespace eckit
+}  // namespace eckit
 
 #endif
