@@ -19,8 +19,7 @@ namespace eckit {
 //----------------------------------------------------------------------------------------------------------------------
 
 
-Configurable::Configurable() :
-    ClassExtent<Configurable>(this) {}
+Configurable::Configurable() : ClassExtent<Configurable>(this) {}
 
 Configurable::~Configurable() {}
 
