@@ -12,7 +12,7 @@
 /// @author Tiago Quintino
 /// @date   August 2016
 
-#include <stdlib.h>
+#include <cstdlib>
 
 #include <algorithm>
 #include <string>
@@ -29,8 +29,7 @@ namespace eckit {
 
 REGISTER_LIBRARY(LibEcKit);
 
-LibEcKit::LibEcKit() :
-    Library("eckit"), abort_handler_(&(::abort)), dontDeregisterFactories_(false) {
+LibEcKit::LibEcKit() : Library("eckit"), abort_handler_(&(::abort)), dontDeregisterFactories_(false) {
     // can't use Resource here (too early in the initialisation)
     dontDeregisterFactories_ = (::getenv("ECKIT_DONT_DEREGISTER_FACTORIES") != nullptr);
 }
