@@ -8,9 +8,9 @@
  * does it submit to any jurisdiction.
  */
 
-#include <ostream>
 #include <sys/file.h>
-#ifdef __linux__ 
+#include <ostream>
+#ifdef __linux__
 #include <linux/errno.h>
 #ifndef ENOTSUPP
 #define ENOTSUPP 524
@@ -91,6 +91,16 @@ BTree<K, V, S, L>::BTree(const PathName& path, bool readOnly, off_t offset) :
     // maxNodeEntries_ << std::endl;
 }
 
+template <class K, class V, int S, class L>
+void BTree<K, V, S, L>::preload() {
+    Page p;
+    loadPage(1, p);
+
+    while (p.right_) {
+        loadPage(p.right_, p);
+    }
+}
+
 
 template <class K, class V, int S, class L>
 BTree<K, V, S, L>::~BTree() {
@@ -642,6 +652,7 @@ size_t BTree<K, V, S, L>::count(unsigned long page) const {
     return c;
 }
 
+
 template <class K, class V, int S, class L>
 void BTree<K, V, S, L>::lockShared() {
     L::lockRange(file_.fileno(), 0, 0, F_SETLKW, F_RDLCK);
@@ -662,24 +673,23 @@ void BTree<K, V, S, L>::unlock() {
 template <class K, class V, int S, class L>
 void BTree<K, V, S, L>::flock() {
 
-    if (::flock(file_.fileno(), readOnly_ ? LOCK_EX : LOCK_SH) < 0)
-    {
+    if (::flock(file_.fileno(), readOnly_ ? LOCK_EX : LOCK_SH) < 0) {
         bool skip = false;
-        #ifdef ENOTSUP
-            if (errno == ENOTSUP) {
-                skip = true;
-            }
-        #endif
-        #ifdef ENOTSUPP
-            if (errno == ENOTSUPP) {
-                skip = true;
-            }
-        #endif
-        #ifdef EOPNOTSUPP
-            if (errno == EOPNOTSUPP) {
-                skip = true;
-            }
-        #endif
+#ifdef ENOTSUP
+        if (errno == ENOTSUP) {
+            skip = true;
+        }
+#endif
+#ifdef ENOTSUPP
+        if (errno == ENOTSUPP) {
+            skip = true;
+        }
+#endif
+#ifdef EOPNOTSUPP
+        if (errno == EOPNOTSUPP) {
+            skip = true;
+        }
+#endif
         if (!skip) {
             std::stringstream ss;
             ss << "Error " << Log::syserr << " locking " << path_;
@@ -691,24 +701,23 @@ void BTree<K, V, S, L>::flock() {
 template <class K, class V, int S, class L>
 void BTree<K, V, S, L>::funlock() {
 
-    if (::flock(file_.fileno(), LOCK_UN) < 0)
-    {
+    if (::flock(file_.fileno(), LOCK_UN) < 0) {
         bool skip = false;
-        #ifdef ENOTSUP
-            if (errno == ENOTSUP) {
-                skip = true;
-            }
-        #endif
-        #ifdef ENOTSUPP
-            if (errno == ENOTSUPP) {
-                skip = true;
-            }
-        #endif
-        #ifdef EOPNOTSUPP
-            if (errno == EOPNOTSUPP) {
-                skip = true;
-            }
-        #endif
+#ifdef ENOTSUP
+        if (errno == ENOTSUP) {
+            skip = true;
+        }
+#endif
+#ifdef ENOTSUPP
+        if (errno == ENOTSUPP) {
+            skip = true;
+        }
+#endif
+#ifdef EOPNOTSUPP
+        if (errno == EOPNOTSUPP) {
+            skip = true;
+        }
+#endif
         if (!skip) {
             std::stringstream ss;
             ss << "Error " << Log::syserr << " unlocking " << path_;
