@@ -19,6 +19,7 @@
 #include <vector>
 
 #include "eckit/exception/Exceptions.h"
+#include "eckit/log/JSON.h"
 
 
 namespace eckit {
@@ -26,20 +27,22 @@ namespace eckit {
 
 template <typename V>
 class DenseSet {
-public:                    // types
+public:  // types
+
     typedef V value_type;  ///< value type
 
 private:  // types
+
     typedef std::vector<value_type> store_t;
 
 public:  // methods
+
     typedef typename store_t::const_reference const_reference;
 
     typedef typename store_t::const_iterator iterator;
     typedef typename store_t::const_iterator const_iterator;
 
-    DenseSet(size_t s = 0) :
-        sorted_(true) {
+    DenseSet(size_t s = 0) : sorted_(true) {
         if (s > 0) {
             reserve(s);
         }
@@ -50,8 +53,10 @@ public:  // methods
     void reserve(size_t s) { values_.reserve(s); }
 
     void insert(const V& v) {
+        if (!values_.empty() && v <= values_.back()) {
+            sorted_ = false;
+        }
         values_.push_back(v);
-        sorted_ = false;
     }
 
     /// @TODO shoudl we implement this?
@@ -128,6 +133,15 @@ public:  // methods
         }
     }
 
+    void json(JSON& s) const {
+        s.startList();
+        const_iterator it = cbegin();
+        for (; it != cend(); ++it) {
+            s << *it;
+        }
+        s.endList();
+    }
+
     bool operator==(const DenseSet& rhs) const { return !operator!=(rhs); }
 
     bool operator!=(const DenseSet& rhs) const { return values_ != rhs.values_; }
@@ -137,7 +151,51 @@ public:  // methods
         return s;
     }
 
-private:              // members
+    friend JSON& operator<<(JSON& s, const DenseSet& m) {
+        m.json(s);
+        return s;
+    }
+
+    void merge(const DenseSet& other) {
+
+        if (other.empty())
+            return;
+
+        if (empty()) {
+            values_ = other.values_;
+            sorted_ = other.sorted_;
+            return;
+        }
+
+        ASSERT(sorted_);
+        ASSERT(other.sorted_);
+
+        int i = 0;
+        int j = 0;
+
+        // n.b. resizes would invalidate iterators --> use indices instead
+
+        while (j < other.values_.size()) {
+
+            if (i >= values_.size() || values_[i] > other.values_[j]) {
+                if (values_.capacity() == values_.size()) {
+                    values_.reserve(std::max(values_.size(), other.values_.size()) * 2);
+                }
+                values_.insert(values_.begin() + i, other.values_[j]);
+                i++;
+                j++;
+            }
+            else if (values_[i] == other.values_[j]) {
+                j++;
+            }
+            else {  // if (*it1 < *it2)
+                i++;
+            }
+        }
+    }
+
+private:  // members
+
     store_t values_;  ///< storage of the values
 
     bool sorted_;
