@@ -19,11 +19,9 @@ namespace eckit {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-PeekHandle::PeekHandle(DataHandle* h) :
-    HandleHolder(h) {}
+PeekHandle::PeekHandle(DataHandle* h) : HandleHolder(h) {}
 
-PeekHandle::PeekHandle(DataHandle& h) :
-    HandleHolder(h) {}
+PeekHandle::PeekHandle(DataHandle& h) : HandleHolder(h) {}
 
 PeekHandle::~PeekHandle() {}
 
@@ -32,8 +30,19 @@ Length PeekHandle::openForRead() {
     return handle().openForRead();
 }
 
-void PeekHandle::skip(const Length&) {
-    NOTIMP;
+void PeekHandle::skip(const Length& len) {
+    if (len == Length(peek_.size())) {
+        peek_.clear();
+    }
+    else if (len < Length(peek_.size())) {
+        for (long i = 0; i < len; ++i) {
+            peek_.pop_front();
+        }
+    }
+    else {
+        // This would involve reads/seeks, etc. Not needed now.
+        NOTIMP;
+    }
 }
 
 unsigned char PeekHandle::peek(size_t n) {
