@@ -33,20 +33,19 @@ void PipeHandle::encode(Stream& s) const {
     s << name_;
 }
 
-PipeHandle::PipeHandle(Stream& s) :
-    DataHandle(s), file_(nullptr), read_(false) {
+PipeHandle::PipeHandle(Stream& s) : DataHandle(s), file_(nullptr), read_(false) {
     s >> name_;
 }
 
-PipeHandle::PipeHandle(const std::string& name) :
-    name_(name), file_(0), read_(false) {}
+PipeHandle::PipeHandle(const std::string& name) : name_(name), file_(0), read_(false) {}
 
 PipeHandle::~PipeHandle() {}
 
 void PipeHandle::open(const char* mode) {
     file_ = ::popen(name_.c_str(), mode);
-    if (file_ == nullptr)
+    if (file_ == nullptr) {
         throw CantOpenFile(name_);
+    }
 }
 
 Length PipeHandle::openForRead() {
@@ -72,8 +71,9 @@ long PipeHandle::write(const void* buffer, long length) {
 }
 
 void PipeHandle::close() {
-    if (file_ == 0)
+    if (file_ == 0) {
         return;
+    }
 
     if (::pclose(file_) != 0) {
         Log::error() << "pclose(" << name_ << ')' << Log::syserr << std::endl;
