@@ -8,7 +8,7 @@
  * does it submit to any jurisdiction.
  */
 
-#include <stdio.h>
+#include <cstdio>
 #include <string>
 
 #include "eckit/exception/Exceptions.h"
@@ -16,8 +16,7 @@
 
 namespace eckit {
 
-StdPipe::StdPipe(const std::string& name, const std::string& mode) :
-    file_(0) {
+StdPipe::StdPipe(const std::string& name, const std::string& mode) : file_(0) {
     file_ = ::popen(name.c_str(), mode.c_str());
 
     if (file_ == 0) {
