@@ -38,7 +38,7 @@ URLHandle::URLHandle(Stream& s) : DataHandle(s) {
     s >> uri_;
 }
 
-URLHandle::URLHandle(const std::string& uri) : uri_(uri) {}
+URLHandle::URLHandle(const std::string& uri, bool useSSL) : uri_(uri), useSSL_(useSSL) {}
 
 URLHandle::~URLHandle() {}
 
@@ -46,6 +46,10 @@ Length URLHandle::estimate() {
     return handle().estimate();
 }
 
+Length URLHandle::size() {
+    return handle().size();
+}
+
 Length URLHandle::openForRead() {
     return handle().estimate();
 }
@@ -73,6 +77,9 @@ void URLHandle::close() {
 DataHandle& URLHandle::handle() {
     if (!handle_) {
         EasyCURL curl;
+        /// IDEA: make the options more generic, eg. EasyCURL curl(opts)
+        // curl.followLocation(true);
+        curl.useSSL(useSSL_);
         handle_.reset(curl.GET(uri_, true).dataHandle());
     }
     return *handle_.get();
