@@ -9,11 +9,11 @@
  */
 
 #include "eckit/io/rados/RadosCluster.h"
-#include "eckit/io/rados/RadosObject.h"
 #include "eckit/io/rados/RadosAttributes.h"
+#include "eckit/io/rados/RadosObject.h"
 
-#include "eckit/exception/Exceptions.h"
 #include "eckit/config/Resource.h"
+#include "eckit/exception/Exceptions.h"
 
 namespace eckit {
 
@@ -36,14 +36,12 @@ public:
 };
 
 
-
 const RadosCluster& RadosCluster::instance() {
     thread_local RadosCluster instance_;
     return instance_;
 }
 
-RadosCluster::RadosCluster():
-    cluster_(0) {
+RadosCluster::RadosCluster() : cluster_(0) {
 
     static const std::string radosClusterName = Resource<std::string>("radosClusterName", "mars");
     static const std::string radosClusterUser = Resource<std::string>("radosClusterUser", "client.mars");
@@ -64,7 +62,6 @@ RadosCluster::RadosCluster():
     RADOS_CALL(rados_conf_read_file(cluster_, radosClusterConfPath.fullName().path().c_str()));
 
     RADOS_CALL(rados_connect(cluster_));
-
 }
 
 RadosCluster::~RadosCluster() {
@@ -82,45 +79,35 @@ RadosCluster::~RadosCluster() {
 
     rados_shutdown(cluster_);
     std::cout << "RADOS_CALL <= rados_shutdown(cluster_)" << std::endl;
-
 }
 
-void RadosCluster::error(int code, const char *msg, const char* file, int line, const char* func) {
+void RadosCluster::error(int code, const char* msg, const char* file, int line, const char* func) {
 
 
     std::ostringstream oss;
-    oss << "RADOS error "
-        << msg << ", file "
-        << file
-        << ", line "
-        << line
-        << ", function "
-        << func
-        << " [" << code
+    oss << "RADOS error " << msg << ", file " << file << ", line " << line << ", function " << func << " [" << code
         << "] (" << strerror(-code) << ")";
     throw SeriousBug(oss.str());
 }
 
 
-
 Length RadosCluster::maxObjectSize() const {
-/*    rados_ioctx_t& ctx=ioCtx("mars");
-    char keys[1000000];
-    size_t keyLen;
-    char vals[1000000];
-    size_t valLen;
+    /*    rados_ioctx_t& ctx=ioCtx("mars");
+        char keys[1000000];
+        size_t keyLen;
+        char vals[1000000];
+        size_t valLen;
 
-    rados_application_metadata_list(ctx, "ceph", keys, &keyLen, vals, &valLen);
+        rados_application_metadata_list(ctx, "ceph", keys, &keyLen, vals, &valLen);
 
-    std::cout << vals <<std::endl;
+        std::cout << vals <<std::endl;
 
-    std::cout << keys <<std::endl;*/
+        std::cout << keys <<std::endl;*/
 
     // TODO: Get from server
     // ceph configuration parameter "osd_max_write_size" default value is 90MB
     static long long len = Resource<long long>("radosMaxObjectSize", 90 * 1024 * 1024);
     return len;
-
 }
 
 
@@ -128,7 +115,7 @@ rados_ioctx_t& RadosCluster::ioCtx(const std::string& pool) const {
     auto j = ctx_.find(pool);
     if (j == ctx_.end()) {
         ctx_[pool] = new RadosIOCtx(cluster_, pool);
-        j = ctx_.find(pool);
+        j          = ctx_.find(pool);
     }
 
     return (*j).second->io_;
@@ -136,7 +123,6 @@ rados_ioctx_t& RadosCluster::ioCtx(const std::string& pool) const {
 
 rados_ioctx_t& RadosCluster::ioCtx(const RadosObject& object) const {
     return ioCtx(object.pool());
-
 }
 
 void RadosCluster::ensurePool(const std::string& pool) const {
@@ -152,23 +138,18 @@ void RadosCluster::ensurePool(const RadosObject& object) const {
 }
 
 
-void RadosCluster::attributes(const RadosObject& object, const RadosAttributes &attr) const {
+void RadosCluster::attributes(const RadosObject& object, const RadosAttributes& attr) const {
 
 
     const char* oid = object.oid().c_str();
-    auto a = attr.attrs();
+    auto a          = attr.attrs();
     for (auto j = a.begin(); j != a.end(); ++j) {
 
         std::cout << "RadosCluster::attributes => [" << (*j).first << "] [" << (*j).second << "]";
 
 
-        RADOS_CALL(rados_setxattr(ioCtx(object),
-                                  oid,
-                                  (*j).first.c_str(),
-                                  (*j).second.c_str(),
-                                  (*j).second.size()));
+        RADOS_CALL(rados_setxattr(ioCtx(object), oid, (*j).first.c_str(), (*j).second.c_str(), (*j).second.size()));
     }
-
 }
 
 RadosAttributes RadosCluster::attributes(const RadosObject& object) const {
@@ -176,15 +157,12 @@ RadosAttributes RadosCluster::attributes(const RadosObject& object) const {
     RadosAttributes attr;
 
 
-
-
-
     rados_xattrs_iter_t iter;
     RADOS_CALL(rados_getxattrs(ioCtx(object), object.oid().c_str(), &iter));
 
 
     for (;;) {
-        const char *name;
+        const char* name;
 
         const char* val;
         size_t len;
@@ -206,14 +184,12 @@ RadosAttributes RadosCluster::attributes(const RadosObject& object) const {
         std::cout << ']' << std::endl;
 
         attr.set(name, std::string(val, val + len));
-
     }
 
     rados_getxattrs_end(iter);
 
 
     return attr;
-
 }
 
 void RadosCluster::remove(const RadosObject& object) const {
