@@ -16,14 +16,10 @@
 #include "eckit/thread/AutoLock.h"
 #include "eckit/thread/Mutex.h"
 
-
-namespace eckit {
-namespace linalg {
-
+namespace eckit::linalg {
 
 //-----------------------------------------------------------------------------
 
-
 static pthread_once_t once                           = PTHREAD_ONCE_INIT;
 static BackendRegistry<LinearAlgebraDense>* backends = nullptr;
 
@@ -87,6 +83,4 @@ LinearAlgebraDense::LinearAlgebraDense(const std::string& name) {
 
 //-----------------------------------------------------------------------------
 
-
-}  // namespace linalg
-}  // namespace eckit
+}  // namespace eckit::linalg
