@@ -16,8 +16,8 @@
 #include <fstream>
 
 #include "eckit/filesystem/PathName.h"
+#include "eckit/io/Buffer.h"
 #include "eckit/log/LogTarget.h"
-#include "eckit/io/ResizableBuffer.h"
 
 namespace eckit {
 
@@ -25,18 +25,21 @@ namespace eckit {
 
 class FileTarget : public LogTarget {
 public:
+
     explicit FileTarget(const PathName& path, size_t bufferSize = 4 * 1024);
     virtual ~FileTarget();
 
 private:
-    virtual void write(const char* start, const char* end) override;
-    virtual void flush() override;
 
-    virtual void print(std::ostream& s) const override;
+    void write(const char* start, const char* end) override;
+    void flush() override;
+
+    void print(std::ostream& s) const override;
 
 private:
+
     std::ofstream out_;
-    ResizableBuffer buffer_;  //< configurable buffer for ofstream
+    Buffer buffer_;  //< configurable buffer for ofstream
     PathName path_;
 };
 
