@@ -24,19 +24,18 @@ namespace eckit {
 
 class MessageTarget : public LineBasedTarget {
 
-public: // methods
+public:  // methods
 
     MessageTarget();
 
 private:
 
-    virtual void line(const char* line);
-    virtual void print(std::ostream& s) const;
-
+    void line(const char* line) override;
+    void print(std::ostream& s) const override;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace eckit
+}  // namespace eckit
 
 #endif
