@@ -23,12 +23,13 @@ namespace eckit {
 class Plural : private eckit::NonCopyable {
 
 public:  // methods
-    Plural(int count, const std::string& s) :
-        s_(s), count_(count) {}
+
+    Plural(int count, const std::string& s) : s_(s), count_(count) {}
 
     ~Plural() {}
 
 protected:  // methods
+
     void print(std::ostream& s) const {
         s << BigNum(count_) << ' ' << s_;
         if (count_ > 1) {
@@ -37,12 +38,14 @@ protected:  // methods
     }
 
 private:  // members
+
     friend std::ostream& operator<<(std::ostream& s, const Plural& p) {
         p.print(s);
         return s;
     }
 
 private:  // members
+
     std::string s_;
 
     int count_;
