@@ -16,8 +16,7 @@
 
 #include "eckit/mpi/DataType.h"
 
-namespace eckit {
-namespace mpi {
+namespace eckit::mpi {
 
 //----------------------------------------------------------------------------------------------------------------------
 
@@ -26,8 +25,8 @@ class Comm;
 class Data {
 
 public:
-    enum Code
-    {
+
+    enum Code {
         CHAR = 0,
         WCHAR,
         SHORT,
@@ -69,7 +68,6 @@ public:
 
 //----------------------------------------------------------------------------------------------------------------------
 
-}  // namespace mpi
-}  // namespace eckit
+}  // namespace eckit::mpi
 
 #endif
