@@ -10,8 +10,11 @@
 
 #include "eckit/mpi/Parallel.h"
 
-#include <errno.h>
 #include <unistd.h>
+#include <atomic>
+#include <cerrno>
+#include <csetjmp>
+#include <csignal>
 #include <limits>
 #include <sstream>
 
@@ -32,21 +35,14 @@ namespace mpi {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-static pthread_once_t once      = PTHREAD_ONCE_INIT;
-static eckit::Mutex* localMutex = 0;
-static size_t initCounter;
-
-static void init() {
-    localMutex  = new eckit::Mutex();
-    initCounter = 0;
-}
+std::atomic<size_t> initCounter{};  // zero-initialized
 
 //----------------------------------------------------------------------------------------------------------------------
 
 class MPIError : public eckit::Exception {
 public:
-    MPIError(const std::string& msg, const eckit::CodeLocation& loc) :
-        eckit::Exception(msg, loc) {
+
+    MPIError(const std::string& msg, const eckit::CodeLocation& loc) : eckit::Exception(msg, loc) {
         std::ostringstream s;
         s << "MPI Error: " << msg << " in " << loc;
         reason(s.str());
@@ -95,6 +91,57 @@ static MPI_Datatype PARALLEL_TWO_LONG_LONG() {
     return mpi_datatype;
 }
 
+struct LocalMutex {
+    operator eckit::Mutex&() { return mutex_; }
+    static LocalMutex& instance() {
+        static LocalMutex instance;
+        return instance;
+    }
+
+private:
+
+    LocalMutex() = default;
+    eckit::Mutex mutex_;
+};
+
+struct WorkaroundSegvAtExit {
+    // This is a workaround for when a SIGSEGV is happening during the
+    // program teardown phase after the main() scope ends. eckit::mpi is designed to
+    // automatically call MPI_Finalize at this point when needed.
+    // Some MPI implementations trigger a SIGSEGV. This is e.g. the case with hpcx-openmpi/2.14.0
+    // with CUDA-aware features enabled.
+    //
+    // To enable the workaround, please export `ECKIT_MPI_WORKAROUND_SEGV_AT_EXIT=1`
+    //
+    // For more details see https://github.com/ecmwf/eckit/pull/171
+
+    static void enabled(bool value) { instance().enabled_ = value; }
+
+    static bool enabled() { return instance().enabled_; }
+
+    static void MPI_Finalize() {
+        // This function calls MPI_Finalize, traps a SIGSEGV when it happens, ignores it,
+        // and restores the SIGSEGV signal handler to the default, to handle further SIGSEGV.
+        static std::jmp_buf sigsegv_occured;
+        std::signal(SIGSEGV, [](int) { std::longjmp(sigsegv_occured, true); });
+        if (setjmp(sigsegv_occured)) {
+            std::signal(SIGSEGV, SIG_DFL);
+            // std::cerr << "WARNING: Trapped SIGSEGV fault during MPI_Finalize() after main()" << std::endl;
+            return;
+        }
+        MPI_CALL(::MPI_Finalize());
+    }
+
+private:
+
+    static WorkaroundSegvAtExit& instance() {
+        static WorkaroundSegvAtExit instance;
+        return instance;
+    }
+    bool enabled_{false};
+};
+
+
 }  // namespace
 
 
@@ -169,27 +216,19 @@ size_t getSize(MPI_Comm comm) {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-Parallel::Parallel(std::string_view name) :
-    Comm(name) /* don't use member initialisation list */ {
-
-    pthread_once(&once, init);
-    eckit::AutoLock<eckit::Mutex> lock(localMutex);
+Parallel::Parallel(std::string_view name) : Comm(name) /* don't use member initialisation list */ {
 
     if (initCounter == 0) {
         initialize();
     }
-    initCounter++;
 
+    initCounter++;
     comm_ = MPI_COMM_WORLD;
     rank_ = getRank(comm_);
     size_ = getSize(comm_);
 }
 
-Parallel::Parallel(std::string_view name, MPI_Comm comm, bool) :
-    Comm(name) /* don't use member initialisation list */ {
-
-    pthread_once(&once, init);
-    eckit::AutoLock<eckit::Mutex> lock(localMutex);
+Parallel::Parallel(std::string_view name, MPI_Comm comm, bool) : Comm(name) /* don't use member initialisation list */ {
 
     if (initCounter == 0) {
         initialize();
@@ -201,15 +240,8 @@ Parallel::Parallel(std::string_view name, MPI_Comm comm, bool) :
     size_ = getSize(comm_);
 }
 
-Parallel::Parallel(std::string_view name, int comm) :
-    Comm(name) {
+Parallel::Parallel(std::string_view name, int comm) : Comm(name) {
 
-    pthread_once(&once, init);
-    eckit::AutoLock<eckit::Mutex> lock(localMutex);
-
-    if (initCounter == 0) {
-        initialize();
-    }
     initCounter++;
 
     comm_ = MPI_Comm_f2c(comm);
@@ -219,9 +251,6 @@ Parallel::Parallel(std::string_view name, int comm) :
 
 Parallel::~Parallel() {
 
-    pthread_once(&once, init);
-    eckit::AutoLock<eckit::Mutex> lock(localMutex);
-
     initCounter--;
 
     if (initCounter == 0) {
@@ -234,6 +263,7 @@ Comm* Parallel::self() const {
 }
 
 void Parallel::initialize() {
+    eckit::AutoLock<eckit::Mutex> lock(LocalMutex::instance());
 
     if (!initialized()) {
 
@@ -247,6 +277,8 @@ void Parallel::initialize() {
 
         std::string MPIInitThread = eckit::Resource<std::string>("MPIInitThread;$ECKIT_MPI_INIT_THREAD", "NONE");
 
+        WorkaroundSegvAtExit::enabled(eckit::Resource<bool>("$ECKIT_MPI_WORKAROUND_SEGV_AT_EXIT", false));
+
         if (MPIInitThread == "NONE") {
             MPI_CALL(MPI_Init(&argc, &argv));
         }
@@ -303,19 +335,22 @@ void Parallel::initialize() {
 
 void Parallel::finalize() {
     if (not finalized()) {
-        MPI_CALL(MPI_Finalize());
+        if (WorkaroundSegvAtExit::enabled()) {
+            WorkaroundSegvAtExit::MPI_Finalize();
+        }
+        else {
+            MPI_CALL(MPI_Finalize());
+        }
     }
 }
 
 bool Parallel::initialized() {
-
     int result = 1;
     MPI_CALL(MPI_Initialized(&result));
     return bool(result);
 }
 
 bool Parallel::finalized() {
-
     int result = 1;
     MPI_CALL(MPI_Finalized(&result));
     return bool(result);
@@ -497,12 +532,12 @@ void Parallel::scatterv(const void* sendbuf, const int sendcounts[], const int d
                           recvbuf, int(recvcount), mpitype, int(root), comm_));
 }
 
-void Parallel::reduce(const void* sendbuf, void* recvbuf, size_t count, Data::Code type, Operation::Code op, size_t root) const {
+void Parallel::reduce(const void* sendbuf, void* recvbuf, size_t count, Data::Code type, Operation::Code op,
+                      size_t root) const {
     ASSERT(count < size_t(std::numeric_limits<int>::max()));
 
     MPI_Datatype mpitype = toType(type);
     MPI_Op mpiop         = toOp(op);
-    ;
 
     MPI_CALL(MPI_Reduce(const_cast<void*>(sendbuf), recvbuf, int(count), mpitype, mpiop, int(root), comm_));
 }
@@ -526,7 +561,6 @@ void Parallel::allReduce(const void* sendbuf, void* recvbuf, size_t count, Data:
 
     MPI_Datatype mpitype = toType(type);
     MPI_Op mpiop         = toOp(op);
-    ;
 
     MPI_CALL(MPI_Allreduce(const_cast<void*>(sendbuf), recvbuf, int(count), mpitype, mpiop, comm_));
 }
@@ -631,16 +665,16 @@ Request Parallel::iSend(const void* send, size_t count, Data::Code type, int des
     return req;
 }
 
-Status Parallel::sendReceiveReplace(void* sendrecv, size_t count, Data::Code type,
-                                    int dest, int sendtag, int source, int recvtag) const {
+Status Parallel::sendReceiveReplace(void* sendrecv, size_t count, Data::Code type, int dest, int sendtag, int source,
+                                    int recvtag) const {
     ASSERT(count < size_t(std::numeric_limits<int>::max()));
 
     MPI_Datatype mpitype = toType(type);
 
     Status status = createStatus();
 
-    MPI_CALL(MPI_Sendrecv_replace(sendrecv, int(count), mpitype,
-                                  dest, sendtag, source, recvtag, comm_, toStatus(status)));
+    MPI_CALL(
+        MPI_Sendrecv_replace(sendrecv, int(count), mpitype, dest, sendtag, source, recvtag, comm_, toStatus(status)));
 
     return status;
 }
@@ -707,7 +741,8 @@ Comm& Parallel::create(const Group& group, const std::string& name) const {
 
 Comm& Parallel::create(const Group& group, int tag, const std::string& name) const {
     MPI_Comm new_mpi_comm;
-    MPI_CALL(MPI_Comm_create_group(comm_, dynamic_cast<const ParallelGroup&>(*group.content_).group_, tag, &new_mpi_comm));
+    MPI_CALL(
+        MPI_Comm_create_group(comm_, dynamic_cast<const ParallelGroup&>(*group.content_).group_, tag, &new_mpi_comm));
     Comm* newcomm = new Parallel(name, new_mpi_comm, true);
     addComm(name.c_str(), newcomm);
     return *newcomm;
