@@ -26,12 +26,13 @@ namespace mpi {
 class Parallel : public eckit::mpi::Comm {
 
 protected:  // methods
+
     template <class T>
     friend class CommBuilder;
 
-    Parallel(const std::string& name);
-    Parallel(const std::string& name, MPI_Comm comm, bool);
-    Parallel(const std::string& name, int comm);
+    Parallel(std::string_view name);
+    Parallel(std::string_view name, MPI_Comm comm, bool);
+    Parallel(std::string_view name, int comm);
 
     ~Parallel() override;
 
@@ -81,11 +82,11 @@ protected:  // methods
     virtual void scatterv(const void* sendbuf, const int sendcounts[], const int displs[], void* recvbuf,
                           size_t recvcount, Data::Code type, size_t root) const override;
 
-    virtual void reduce(const void* sendbuf, void* recvbuf, size_t count, Data::Code type,
-                        Operation::Code op, size_t root) const override;
+    virtual void reduce(const void* sendbuf, void* recvbuf, size_t count, Data::Code type, Operation::Code op,
+                        size_t root) const override;
 
-    virtual void reduceInPlace(void* sendrecvbuf, size_t count, Data::Code type,
-                               Operation::Code op, size_t root) const override;
+    virtual void reduceInPlace(void* sendrecvbuf, size_t count, Data::Code type, Operation::Code op,
+                               size_t root) const override;
 
     virtual void allReduce(const void* sendbuf, void* recvbuf, size_t count, Data::Code type,
                            Operation::Code op) const override;
@@ -114,8 +115,8 @@ protected:  // methods
 
     Request iSend(const void* send, size_t count, Data::Code type, int dest, int tag) const override;
 
-    virtual Status sendReceiveReplace(void* sendrecv, size_t count, Data::Code type,
-                                      int dest, int sendtag, int source, int recvtag) const override;
+    virtual Status sendReceiveReplace(void* sendrecv, size_t count, Data::Code type, int dest, int sendtag, int source,
+                                      int recvtag) const override;
 
     eckit::SharedBuffer broadcastFile(const eckit::PathName& filepath, size_t root) const override;
 
@@ -142,6 +143,7 @@ protected:  // methods
     int communicator() const override;
 
 public:  // static methods
+
     static Status createStatus();
 
     static MPI_Status* toStatus(Status&);
@@ -149,12 +151,15 @@ public:  // static methods
     static MPI_Request* toRequest(Request&);
 
 public:
+
     /// Access internal MPI_Comm.
     /// Warning! Do not use the return value to free or modify the MPI communicator!
     MPI_Comm MPIComm() const;
 
-private:                         // methods
-    friend class ParallelGroup;  // Groups should not call free if mpi has been finalized. Hence PrallelGroup needs to query finalized()
+private:  // methods
+
+    friend class ParallelGroup;  // Groups should not call free if mpi has been finalized. Hence PrallelGroup needs to
+                                 // query finalized()
 
     static void initialize();
 
@@ -165,6 +170,7 @@ private:                         // methods
     static bool finalized();
 
 private:  // members
+
     MPI_Comm comm_;
 };
 
