@@ -10,8 +10,8 @@
 
 #include "eckit/mpi/Serial.h"
 
-#include <cerrno>
 #include <unistd.h>
+#include <cerrno>
 
 #include <cstring>
 #include <deque>
@@ -36,6 +36,7 @@ namespace eckit::mpi {
 
 class SerialRequestPool : private NonCopyable {
 public:
+
     static SerialRequestPool& instance() {
         static SerialRequestPool request_pool;
         return request_pool;
@@ -105,6 +106,7 @@ public:
     static constexpr int anyTag() { return Serial::Constants::anyTag(); }
 
 private:
+
     Request registerRequest(SerialRequest* request) {
         ++n_;
         if (size_t(n_) == requests_.size()) {
@@ -134,14 +136,12 @@ private:
 
 //----------------------------------------------------------------------------------------------------------------------
 
-Serial::Serial(std::string_view name) :
-    Comm(name) {
+Serial::Serial(std::string_view name) : Comm(name) {
     rank_ = 0;
     size_ = 1;
 }
 
-Serial::Serial(std::string_view name, int) :
-    Comm(name) {
+Serial::Serial(std::string_view name, int) : Comm(name) {
     rank_ = 0;
     size_ = 1;
 }
@@ -333,7 +333,8 @@ void Serial::scatterv(const void* sendbuf, const int[], const int[], void* recvb
     }
 }
 
-void Serial::reduce(const void* sendbuf, void* recvbuf, size_t count, Data::Code type, Operation::Code, size_t root) const {
+void Serial::reduce(const void* sendbuf, void* recvbuf, size_t count, Data::Code type, Operation::Code,
+                    size_t root) const {
     if (recvbuf != sendbuf && count > 0) {
         memcpy(recvbuf, sendbuf, count * dataSize[type]);
     }
@@ -400,8 +401,8 @@ Status Serial::receive(void* recv, size_t count, Data::Code type, int /*source*/
     return Status(st);
 }
 
-Status Serial::sendReceiveReplace(void* sendrecv, size_t count, Data::Code type,
-                                  int /*dest*/, int sendtag, int /*source*/, int recvtag) const {
+Status Serial::sendReceiveReplace(void* sendrecv, size_t count, Data::Code type, int /*dest*/, int sendtag,
+                                  int /*source*/, int recvtag) const {
     AutoLock<SerialRequestPool> lock(SerialRequestPool::instance());
     SerialRequestPool::instance().createSendRequest(sendrecv, count, type, sendtag);
     ReceiveRequest recv_request(sendrecv, count, type, recvtag);
