@@ -16,13 +16,11 @@ namespace eckit::mpi {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-Status::Status() :
-    content_(new NullStatus()) {
+Status::Status() : content_(new NullStatus()) {
     content_->attach();
 }
 
-Status::Status(StatusContent* p) :
-    content_(p) {
+Status::Status(StatusContent* p) : content_(p) {
     ASSERT(p);
     content_->attach();
 }
@@ -31,8 +29,7 @@ Status::~Status() {
     content_->detach();
 }
 
-Status::Status(const Status& s) :
-    content_(s.content_) {
+Status::Status(const Status& s) : content_(s.content_) {
     content_->attach();
 }
 
