@@ -23,8 +23,8 @@ ProxiedTCPClient::ProxiedTCPClient(const std::string& proxyHost, int proxyPort,
 
 ProxiedTCPClient::~ProxiedTCPClient() {}
 
-net::TCPSocket& ProxiedTCPClient::connect(const std::string& host, int port, int retries, int timeout) {
-    net::TCPSocket& socket = TCPClient::connect(proxy_.hostname(), proxy_.port(), retries, timeout);
+net::TCPSocket& ProxiedTCPClient::connect(const std::string& host, int port, int retries, int timeout, int retryDelay) {
+    net::TCPSocket& socket = TCPClient::connect(proxy_.hostname(), proxy_.port(), retries, timeout, retryDelay);
 
     socket.debug(debug_.on);
 
