@@ -13,12 +13,9 @@
 #include "eckit/net/TelnetUser.h"
 #include "eckit/runtime/Monitor.h"
 
+namespace eckit::net {
 
-namespace eckit {
-namespace net {
-
-Telnet::Telnet(int port) :
-    NetService(port) {}
+Telnet::Telnet(int port) : NetService(port) {}
 
 Telnet::~Telnet() {}
 
@@ -27,6 +24,4 @@ net::NetUser* Telnet::newUser(net::TCPSocket& protocol) const {
     return new TelnetUser(protocol);
 }
 
-
-}  // namespace net
-}  // namespace eckit
+}  // namespace eckit::net
