@@ -12,9 +12,7 @@
 /// @author Tiago Quintino
 /// @date Apr 2015
 
-
-#ifndef eckit_option_FactoryOption_H
-#define eckit_option_FactoryOption_H
+#pragma once
 
 #include <iosfwd>
 
@@ -27,24 +25,31 @@ namespace eckit::option {
 ///       the validity of input received, and just returns the appropriate string
 
 template <class T>
-class FactoryOption : public Option {
+class FactoryOption : public BaseOption<std::string> {
 public:
-    FactoryOption(const std::string& name, const std::string& description);
 
-    ~FactoryOption() override;  // Change to virtual if base class
+    using base_t = BaseOption<std::string>;
+
+    FactoryOption(const std::string& name, const std::string& description);
+    FactoryOption(const std::string& name, const std::string& description, std::string default_value);
+
+    ~FactoryOption() override = default;
+
+    size_t set(Configured&, size_t values, args_t::const_iterator begin, args_t::const_iterator end) const override;
 
 protected:
-    void print(std::ostream&) const override;  // Change to virtual if base class
+
+    void print(std::ostream&) const override;
 
 private:
-    using Option::set;
 
-    void set(const std::string& value, Configured&) const override;
+    void set_value(const std::string& value, Configured&) const override;
+
+    [[nodiscard]] std::string translate(const std::string& value) const override;
+
     void copy(const Configuration& from, Configured& to) const override;
 };
 
 }  // namespace eckit::option
 
 #include "eckit/option/FactoryOption.cc"
-
-#endif
