@@ -22,13 +22,13 @@
 namespace eckit {
 
 
-JSONParser::JSONParser(std::istream& in) :
-    ObjectParser(in, false, false) {}
+JSONParser::JSONParser(std::istream& in) : ObjectParser(in, false, false) {}
 
 Value JSONParser::decodeFile(const PathName& path) {
     std::ifstream in(std::string(path).c_str());
-    if (!in)
+    if (!in) {
         throw eckit::CantOpenFile(path);
+    }
     return JSONParser(in).parse();
 }
 
