@@ -42,8 +42,7 @@ struct YAMLItem : public Counted {
         return v;
     }
 
-    YAMLItem(long indent = 0, const Value& value = Value()) :
-        indent_(indent), value_(value) {}
+    YAMLItem(long indent = 0, const Value& value = Value()) : indent_(indent), value_(value) {}
 
     virtual ~YAMLItem() {
         // std::cout << "~YAMLItem " << value_ << std::endl;
@@ -65,8 +64,8 @@ class YAMLItemLock {
     const YAMLItem* item_;
 
 public:
-    YAMLItemLock(const YAMLItem* item) :
-        item_(0) { set(item); }
+
+    YAMLItemLock(const YAMLItem* item) : item_(0) { set(item); }
     ~YAMLItemLock() { set(0); }
 
     void set(const YAMLItem* item) {
@@ -89,8 +88,7 @@ struct YAMLItemEOF : public YAMLItem {
 
     virtual Value value(YAMLParser& parser) const { return Value(); }
 
-    YAMLItemEOF() :
-        YAMLItem(-1) {}
+    YAMLItemEOF() : YAMLItem(-1) {}
     virtual bool isEOF() const { return true; }
 };
 
@@ -131,8 +129,7 @@ struct YAMLItemStartDocument : public YAMLItem {
     }
 
 
-    YAMLItemStartDocument() :
-        YAMLItem(-1) {}
+    YAMLItemStartDocument() : YAMLItem(-1) {}
 
 
     virtual bool isStartDocument() const { return true; }
@@ -147,8 +144,7 @@ struct YAMLItemValue : public YAMLItem {
 
     virtual Value value(YAMLParser& parser) const { return value_; }
 
-    YAMLItemValue(size_t indent, const Value& value) :
-        YAMLItem(indent, value) {}
+    YAMLItemValue(size_t indent, const Value& value) : YAMLItem(indent, value) {}
 };
 
 struct YAMLItemAnchor : public YAMLItem {
@@ -165,8 +161,7 @@ struct YAMLItemAnchor : public YAMLItem {
         return v;
     }
 
-    YAMLItemAnchor(size_t indent, const Value& value) :
-        YAMLItem(indent, value) {}
+    YAMLItemAnchor(size_t indent, const Value& value) : YAMLItem(indent, value) {}
 };
 
 struct YAMLItemReference : public YAMLItem {
@@ -177,8 +172,7 @@ struct YAMLItemReference : public YAMLItem {
 
     virtual Value value(YAMLParser& parser) const { return parser.anchor(value_); }
 
-    YAMLItemReference(size_t indent, const Value& value) :
-        YAMLItem(indent, value) {}
+    YAMLItemReference(size_t indent, const Value& value) : YAMLItem(indent, value) {}
 };
 
 struct YAMLItemKey : public YAMLItem {
@@ -190,8 +184,7 @@ struct YAMLItemKey : public YAMLItem {
         s << "YAMLItemKey[value=" << value_ << ", indent=" << indent_ << "]";
     }
 
-    YAMLItemKey(YAMLItem* item) :
-        YAMLItem(item->indent_, item->value_) {
+    YAMLItemKey(YAMLItem* item) : YAMLItem(item->indent_, item->value_) {
 
         YAMLItemLock lock(item);  // Trigger deletion
     }
@@ -315,8 +308,7 @@ struct YAMLItemEntry : public YAMLItem {
 
     virtual void print(std::ostream& s) const { s << "YAMLItemEntry[indent=" << indent_ << "]"; }
 
-    YAMLItemEntry(size_t indent) :
-        YAMLItem(indent) {}
+    YAMLItemEntry(size_t indent) : YAMLItem(indent) {}
 
     Value value(YAMLParser& parser) const {
         std::vector<Value> l;
@@ -377,16 +369,14 @@ struct YAMLItemEndDocument : public YAMLItem {
 
     virtual Value value(YAMLParser& parser) const { return Value(); }
 
-    YAMLItemEndDocument() :
-        YAMLItem(-1) {}
+    YAMLItemEndDocument() : YAMLItem(-1) {}
 
 
     virtual bool isEndDocument() const { return true; }
 };
 
 
-YAMLParser::YAMLParser(std::istream& in) :
-    ObjectParser(in, true, true), last_(0) {
+YAMLParser::YAMLParser(std::istream& in) : ObjectParser(in, true, true), last_(0) {
     stop_.push_back(0);
     comma_.push_back(0);
     colon_.push_back(0);
@@ -430,12 +420,8 @@ static Value toValue(std::string& s) {
     static Regex integer8("^0o[0-7_]+$", false);
     static Regex integer10("^[-+]?[0-9_]+$", false);
     static Regex integer16("0x[0-9a-fA-F_]+$", false);
-    static Regex float10(
-        "^[-+]?(\\.[0-9_]+|[0-9_]+(\\.[0-9_]*)?)([eE][-+]?[0-9]+)?$",
-        false);
-    static Regex floatspecial(
-        "^(\\.(nan|NaN|NAN)|[-+]?\\.(inf|Inf|INF))$",
-        false);
+    static Regex float10("^[-+]?(\\.[0-9_]+|[0-9_]+(\\.[0-9_]*)?)([eE][-+]?[0-9]+)?$", false);
+    static Regex floatspecial("^(\\.(nan|NaN|NAN)|[-+]?\\.(inf|Inf|INF))$", false);
     // static Regex time("[0-9]+:[0-9]+:[0-9]+$", false);
 
     /*
@@ -462,6 +448,7 @@ static Value toValue(std::string& s) {
                     s.erase(remove(s.begin(), s.end(), '_'), s.end());
                     return Value(strtol(s.substr(2).c_str(), 0, 16));
                 }
+                [[fallthrough]];
 
             case '1':
             case '2':
@@ -478,6 +465,7 @@ static Value toValue(std::string& s) {
                     long long d = Translator<std::string, long long>()(s);
                     return Value(d);
                 }
+                [[fallthrough]];
 
             case '.':
 
