@@ -25,6 +25,7 @@ class Buffer;
 
 class MemoryStream : public Stream {
 public:
+
     MemoryStream(const Buffer&);
     MemoryStream(Buffer&);
 
@@ -33,14 +34,15 @@ public:
 
     ~MemoryStream();
 
-    virtual long read(void*, long) override;
-    virtual long write(const void*, long) override;
-    virtual void rewind() override;
-    virtual std::string name() const override;
+    long read(void*, long) override;
+    long write(const void*, long) override;
+    void rewind() override;
+    std::string name() const override;
 
     size_t position() const;
 
 private:  // members
+
     char* address_;
     const size_t size_;
 
