@@ -13,14 +13,11 @@
 #include "eckit/sql/SQLOutput.h"
 #include "eckit/utils/Translator.h"
 
-namespace eckit {
-namespace sql {
-namespace type {
+namespace eckit::sql::type {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-SQLInt::SQLInt(const std::string& name) :
-    SQLType(name) {}
+SQLInt::SQLInt(const std::string& name) : SQLType(name) {}
 
 SQLInt::~SQLInt() {}
 
@@ -38,6 +35,4 @@ std::string SQLInt::asString(const double* val) const {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-}  // namespace type
-}  // namespace sql
-}  // namespace eckit
+}  // namespace eckit::sql::type
