@@ -23,6 +23,7 @@ namespace eckit {
 template <class T>
 class Once : private NonCopyable {
 public:
+
     // -- Contructors
 
     Once();
@@ -36,6 +37,7 @@ public:
     operator T&();
 
 private:
+
     // -- Members
     T* value_;
 
@@ -58,8 +60,7 @@ template <class T>
 pthread_mutex_t Once<T>::mutex_;
 
 template <class T>
-Once<T>::Once() :
-    value_(0) {}
+Once<T>::Once() : value_(0) {}
 
 template <class T>
 Once<T>::~Once() {}
