@@ -8,6 +8,7 @@
  * does it submit to any jurisdiction.
  */
 
+#include <cmath>
 #include <locale>
 
 #include "eckit/eckit.h"
@@ -18,14 +19,11 @@
 namespace eckit {
 
 //----------------------------------------------------------------------------------------------------------------------
-DateTime::DateTime(const Date& d, const Time& t) :
-    date_(d), time_(t) {}
+DateTime::DateTime(const Date& d, const Time& t) : date_(d), time_(t) {}
 
-DateTime::DateTime(const DateTime& other) :
-    date_(other.date_), time_(other.time_) {}
+DateTime::DateTime(const DateTime& other) : date_(other.date_), time_(other.time_) {}
 
-DateTime::DateTime(double julian) :
-    date_(long(julian), true), time_((julian - long(julian)) * 24 * 60 * 60) {}
+DateTime::DateTime(double julian) : date_(long(julian), true), time_((julian - long(julian)) * 24 * 60 * 60) {}
 
 DateTime::DateTime(const std::string& s) {
     Tokenizer parse(" ");
@@ -121,20 +119,21 @@ DateTime& DateTime::operator=(const DateTime& other) {
 }
 
 Second DateTime::operator-(const DateTime& other) const {
-    Second date = (date_ - other.date_) * 24 * 3600;
+    Second date = (date_ - other.date_) * 86400;
     Second time = time_ - other.time_;
 
     return date + time;
 }
 
 DateTime DateTime::operator+(const Second& s) const {
-    Date d = date();
-    long t = time();
-    d += long(s) / (24 * 3600);
-    t += long(s) % (24 * 3600);
-    while (t >= 3600 * 24) {
+    Date d    = date();
+    double t  = time();
+    long days = std::lround(s) / (86400);
+    d += days;
+    t += s - days * (86400);
+    if (t >= 86400) {
         d += 1;
-        t -= 3600 * 24;
+        t -= 86400;
     }
 
     return DateTime(d, Second(t));
@@ -144,8 +143,8 @@ DateTime DateTime::round(const Second& rnd) const {
     long long seconds = double(date_.julian_) * 24.0 * 3600 + Second(time_);
     seconds           = (seconds / long(rnd)) * rnd;
 
-    long d   = seconds / (3600 * 24);
-    Second t = seconds % (3600 * 24);
+    long d   = seconds / (86400);
+    Second t = seconds % (86400);
 
     return DateTime(Date(d, true), Time(t));
 }
