@@ -16,19 +16,19 @@
 namespace eckit {
 
 class Buffer;
-class ResizableBuffer;
 
 //----------------------------------------------------------------------------------------------------------------------
 
 class BZip2Compressor : public eckit::Compressor {
 
 public:  // methods
+
     BZip2Compressor();
 
-    virtual ~BZip2Compressor() override;
+    ~BZip2Compressor() override;
 
-    virtual size_t compress(const eckit::Buffer& in, eckit::ResizableBuffer& out) const override;
-    virtual size_t uncompress(const eckit::Buffer& in, eckit::ResizableBuffer& out) const override;
+    size_t compress(const void* in, size_t len, eckit::Buffer& out) const override;
+    void uncompress(const void* in, size_t len, eckit::Buffer& out, size_t outlen) const override;
 
 protected:  // methods
 };
