@@ -34,11 +34,11 @@ class Optional;
 template <typename T, typename Enable = void>
 class OptionalBase {
 public:
-    ~OptionalBase() {
-        static_cast<Optional<T>*>(this)->reset();
-    }
+
+    ~OptionalBase() { static_cast<Optional<T>*>(this)->reset(); }
 
 protected:
+
     // Union with members that have non-trivial destructors need to define a destructor
     union opt_value_type {
         None none;
@@ -50,12 +50,15 @@ protected:
 template <typename T>
 class OptionalBase<T, typename std::enable_if<std::is_trivially_destructible<T>::value>::type> {
 public:
+
     ~OptionalBase() = default;
 
 protected:
-    // Using union instead of a char* array with alignas allows getting rid of reinterpret_cast (which might be implementation dependent) and allows defining constexpr for trivial types
-    // An implementation in C++14 would also use unions to have full constexpr support
-    // Union with members that have trivial destructors can have a default destructor
+
+    // Using union instead of a char* array with alignas allows getting rid of reinterpret_cast (which might be
+    // implementation dependent) and allows defining constexpr for trivial types An implementation in C++14 would also
+    // use unions to have full constexpr support Union with members that have trivial destructors can have a default
+    // destructor
     union opt_value_type {
         None none;
         T value;
@@ -66,51 +69,48 @@ protected:
 template <typename T>
 class Optional : public OptionalBase<T> {
 protected:
+
     struct TagValueConstructor {};
     struct TagCopyConstructor {};
     // struct TagMoveConstructor {};
 
-    // Value constructor for trivial classes. No construction happening, can assign directly and hence make it a constexpr
+    // Value constructor for trivial classes. No construction happening, can assign directly and hence make it a
+    // constexpr
     template <typename TV, typename std::enable_if<(std::is_trivial<TV>::value), bool>::type = true>
-    constexpr Optional(TagValueConstructor, TV&& v) :
-        val_{.value = std::forward<TV>(v)}, hasValue_(true) {}
+    constexpr Optional(TagValueConstructor, TV&& v) : val_{.value = std::forward<TV>(v)}, hasValue_(true) {}
 
     // Value constructor for non-trivial classes - enforce construction with placement
     template <typename TV, typename std::enable_if<!(std::is_trivial<TV>::value), bool>::type = true>
-    Optional(TagValueConstructor, TV&& v) :
-        val_{None{}}, hasValue_(true) {
+    Optional(TagValueConstructor, TV&& v) : val_{None{}}, hasValue_(true) {
         new (&val_.value) T(std::forward<TV>(v));
     }
 
-    // Copy constructor for trivial classes. No construction happening, can assign directly and hence make it a constexpr
+    // Copy constructor for trivial classes. No construction happening, can assign directly and hence make it a
+    // constexpr
     template <typename TV, typename std::enable_if<(std::is_trivial<TV>::value), bool>::type = true>
     constexpr Optional(TagCopyConstructor, const TV& other) :
         val_{.value = other.val_.value}, hasValue_(other.hasValue_) {}
 
     // Copy constructor for non-trivial classes - enforce construction with placement
     template <typename TV, typename std::enable_if<!(std::is_trivial<TV>::value), bool>::type = true>
-    Optional(TagCopyConstructor, const TV& other) :
-        val_{None{}}, hasValue_(other.hasValue_) {
+    Optional(TagCopyConstructor, const TV& other) : val_{None{}}, hasValue_(other.hasValue_) {
         if (hasValue_) {
             new (&val_.value) T(other.val_.value);
         }
     }
 
 public:  // methods
-    constexpr Optional() noexcept :
-        val_{None{}}, hasValue_(false) {}
 
-    constexpr explicit Optional(T&& v) noexcept :
-        Optional(TagValueConstructor{}, std::move(v)) {}
+    constexpr Optional() noexcept : val_{None{}}, hasValue_(false) {}
 
-    constexpr explicit Optional(const T& v) :
-        Optional(TagValueConstructor{}, v) {}
+    constexpr explicit Optional(T&& v) noexcept : Optional(TagValueConstructor{}, std::move(v)) {}
 
-    constexpr Optional(const Optional<T>& rhs) :
-        Optional(TagCopyConstructor{}, rhs) {}
+    constexpr explicit Optional(const T& v) : Optional(TagValueConstructor{}, v) {}
+
+    constexpr Optional(const Optional<T>& rhs) : Optional(TagCopyConstructor{}, rhs) {}
 
     ~Optional() = default;
-    
+
     void reset() noexcept {
         if (hasValue_) {
             val_.value.~T();
@@ -118,10 +118,10 @@ public:  // methods
         }
     };
 
-    // constexpr move constructor only possible in C++14 because hasValue_ needs to be accessed conditionally and new (*ptr) should be used to initialize tho value
-    // Also trivial objects would need to modify rhs.hasValue_ to not break semantics, which is only possible in C++14;
-    Optional(Optional<T>&& rhs) noexcept :
-        val_{None{}}, hasValue_(rhs.hasValue_) {
+    // constexpr move constructor only possible in C++14 because hasValue_ needs to be accessed conditionally and new
+    // (*ptr) should be used to initialize tho value Also trivial objects would need to modify rhs.hasValue_ to not
+    // break semantics, which is only possible in C++14;
+    Optional(Optional<T>&& rhs) noexcept : val_{None{}}, hasValue_(rhs.hasValue_) {
         if (hasValue_) {
             new (&val_.value) T(std::move(rhs.val_.value));
         }
@@ -132,7 +132,7 @@ public:  // methods
         if (this == &other) {
             return *this;
         }
-        
+
         if (hasValue_ && other.hasValue_) {
             val_.value = other.value();
         }
@@ -153,19 +153,19 @@ public:  // methods
         }
 
         if (hasValue_ && other.hasValue_) {
-            val_.value      = std::move(other.value());
+            val_.value = std::move(other.value());
         }
         else if (!hasValue_ && other.hasValue_) {
             // Explicitly construct here, previous value has been deleted.
             new (&val_.value) T(std::move(other.value()));
-            hasValue_       = true;
+            hasValue_ = true;
         }
         else if (hasValue_ && !other.hasValue_) {
             reset();
         }
         return *this;
     }
-    
+
     Optional<T>& operator=(const None&) {
         reset();
         return *this;
@@ -173,7 +173,9 @@ public:  // methods
 
     // The std::optional also seems to define a general assignment and does perfect forwarding.
     // This allows also passing other types from which the wrapped type T can be constructed or assigned
-    template <typename U, typename enable = typename std::enable_if<((!std::is_same<typename std::decay<U>::type, Optional<T>>::value) && (std::is_constructible<T, U>::value) && (std::is_assignable<T&, U>::value))>::type>
+    template <typename U, typename enable = typename std::enable_if<
+                              ((!std::is_same<typename std::decay<U>::type, Optional<T>>::value) &&
+                               (std::is_constructible<T, U>::value) && (std::is_assignable<T&, U>::value))>::type>
     Optional<T>& operator=(U&& arg) {
         if (!hasValue_) {
             // Explicitly forward construct here, previous value has been deleted.
@@ -197,7 +199,9 @@ public:  // methods
     }
 
     // Force construct an value by forwarding arguments
-    template <class U, class... Args, typename enable = typename std::enable_if<std::is_constructible<T, std::initializer_list<U>&, Args&&...>::value>::type>
+    template <class U, class... Args,
+              typename enable =
+                  typename std::enable_if<std::is_constructible<T, std::initializer_list<U>&, Args&&...>::value>::type>
     T& emplace(std::initializer_list<U> ilist, Args&&... args) {
         reset();
         new (&val_.value) T(ilist, std::forward<Args>(args)...);
@@ -205,61 +209,46 @@ public:  // methods
         return val_.value;
     }
 
-    constexpr bool has_value() const {
-        return hasValue_;
-    }
-    explicit constexpr operator bool() const {
-        return has_value();
-    }
+    constexpr bool has_value() const { return hasValue_; }
+    explicit constexpr operator bool() const { return has_value(); }
 
     const T& value() const& {
-        if (!hasValue_)
+        if (!hasValue_) {
             throw eckit::Exception("Optional has no value.");
+        }
         return val_.value;
     }
     T& value() & {
-        if (!hasValue_)
+        if (!hasValue_) {
             throw eckit::Exception("Optional has no value.");
+        }
         return val_.value;
     }
     T&& value() && {
-        if (!hasValue_)
+        if (!hasValue_) {
             throw eckit::Exception("Optional has no value.");
+        }
         return std::move(val_.value);
     }
 
-    constexpr const T& operator*() const& {
-        return val_.value;
-    }
-    T& operator*() & {
-        return val_.value;
-    }
-    T&& operator*() && {
-        return std::move(val_.value);
-    }
+    constexpr const T& operator*() const& { return val_.value; }
+    T& operator*() & { return val_.value; }
+    T&& operator*() && { return std::move(val_.value); }
 
     // TODO: Discuss about removing this in favour of * and -> (simialy to std::optional)
-    constexpr const T& operator()() const& {
-        return value();
-    }
-    T& operator()() & {
-        return value();
-    }
-    T&& operator()() && {
-        return value();
-    }
+    constexpr const T& operator()() const& { return value(); }
+    T& operator()() & { return value(); }
+    T&& operator()() && { return value(); }
 
-    constexpr const T* operator->() const& {
-        return &val_.value;
-    }
-    T* operator->() & {
-        return &val_.value;
-    }
+    constexpr const T* operator->() const& { return &val_.value; }
+    T* operator->() & { return &val_.value; }
 
 private:
+
     friend OptionalBase<T>;
 
-    // While using ntd_opt_value_type would be just fine for both cases, doing the conditional type switch allows creating constexpr for optional trivial types
+    // While using ntd_opt_value_type would be just fine for both cases, doing the conditional type switch allows
+    // creating constexpr for optional trivial types
     using opt_value_type = typename OptionalBase<T>::opt_value_type;
 
     opt_value_type val_;
