@@ -24,11 +24,9 @@ ClassSpec BoolContent::classSpec_ = {
 };
 Reanimator<BoolContent> BoolContent::reanimator_;
 
-BoolContent::BoolContent(bool l) :
-    value_(l) {}
+BoolContent::BoolContent(bool l) : value_(l) {}
 
-BoolContent::BoolContent(Stream& s) :
-    Content(s), value_(false) {
+BoolContent::BoolContent(Stream& s) : Content(s), value_(false) {
     s >> value_;
 }
 
@@ -58,11 +56,13 @@ int BoolContent::compare(const Content& other) const {
 int BoolContent::compareBool(const BoolContent& other) const {
     bool equal = !(value_ - other.value_);
 
-    if (equal)
+    if (equal) {
         return 0;  // both equal in value, hence 0
+    }
 
-    if (!value_)
+    if (!value_) {
         return -1;  // this is false, hence smaller than other
+    }
 
     return 1;  // this is true, hence larger than other
 }
