@@ -96,23 +96,24 @@ class FDBForker : public ProcessControler {
     }
 
 public:
-    FDBForker(net::TCPSocket& socket) :
-        ProcessControler(true), socket_(socket) {}
+
+    FDBForker(net::TCPSocket& socket) : ProcessControler(true), socket_(socket) {}
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
 class FDBSvrApp : public Application {
 public:
-    FDBSvrApp(int argc, char** argv) :
-        Application(argc, argv, "HOME") {}
+
+    FDBSvrApp(int argc, char** argv) : Application(argc, argv, "HOME") {}
 
     ~FDBSvrApp() {}
 
 private:
+
     int port_;
 
-    FDBSvrApp(const FDBSvrApp&) = delete;
+    FDBSvrApp(const FDBSvrApp&)            = delete;
     FDBSvrApp& operator=(const FDBSvrApp&) = delete;
 
     virtual void run() {
