@@ -37,10 +37,10 @@ class Restart : public DataHandle, public HandleHolder {
     Length nextStop_;
 
 public:
+
     static size_t increment() { return 77773; }  // a prime larger than 4 KiB
 
-    Restart(DataHandle* h) :
-        HandleHolder(h), total_(0) { nextStop_ = increment(); }
+    Restart(DataHandle* h) : HandleHolder(h), total_(0) { nextStop_ = increment(); }
 
     virtual Length openForRead() { NOTIMP; }
 
@@ -95,6 +95,7 @@ public:
 
 class Tester {
 public:
+
     void setup();
     void teardown();
     void test_write();
